@@ -1,4 +1,6 @@
-int selection_box(void **list, char *needs_mark, int nlines, char type, int what_help, char *heading);
+#include "mt.h"
+
+int selection_box(void **list, char *needs_mark, int nlines, selbox_type_t type, int what_help, char *heading);
 int select_window(int what_help, char *heading);
 proginfo * select_subwindow(int f_index, int what_help, char *heading);
 char * select_file(char *input, int what_help);
