@@ -16,8 +16,12 @@
 #include <stropts.h>
 #endif
 #ifndef AIX
+#if defined(__FreeBSD__)
+#include <termios.h>
+#else
 #include <sys/termios.h> /* needed on Solaris 8 */
 #endif
+#endif
 #include <sys/socket.h>
 #include <netinet/in.h>
 
@@ -159,7 +163,7 @@ char * edit_string(NEWWIN *win, int win_y, int win_x, int win_width, int max_wid
 		string[copy_len] = 0x00;
 
 		str_pos = dummy;
-		mvwprintw(win -> win, win_y, win_x, &string[dummy]);
+		mvwprintw(win -> win, win_y, win_x, "%s", &string[dummy]);
 		x = strlen(string) - dummy;
 	}
 	else
@@ -608,7 +612,7 @@ void escape_print(NEWWIN *win, int y, int x, char *str)
 void win_header(NEWWIN *win, char *str)
 {
 	wattron(win -> win, A_BOLD);
-	mvwprintw(win -> win, 1, 2, str);
+	mvwprintw(win -> win, 1, 2, "%s", str);
 	wattroff(win -> win, A_BOLD);
 }
 
